aboutsummaryrefslogtreecommitdiffstats
path: root/lib/sasl/test/systools_SUITE.erl
diff options
context:
space:
mode:
authorSiri Hansen <[email protected]>2011-10-13 11:53:51 +0200
committerSiri Hansen <[email protected]>2011-11-17 16:47:28 +0100
commitbe04ed7beceeb4bcf5db7807e86df87e28c9f4b9 (patch)
tree3c5feabbfb50156cfc6e8025d9c20dd786fb9cd0 /lib/sasl/test/systools_SUITE.erl
parent1dec251ad333045847b75b8ee75d4bff4237108e (diff)
downloadotp-be04ed7beceeb4bcf5db7807e86df87e28c9f4b9.tar.gz
otp-be04ed7beceeb4bcf5db7807e86df87e28c9f4b9.tar.bz2
otp-be04ed7beceeb4bcf5db7807e86df87e28c9f4b9.zip
Distinguish restart_new_emulator from restart_emulator in upgrade instructions
Earlier, there was only one valid instruction to restart the emulator in an appup/relup script, 'restart_new_emulator'. A new instuction, 'restart_emulator', is now added, and the meaning is as follows: 'restart_new_emulator' is mainly for the core applications (erts, kernel, stdlib and sasl), and it indicates that there is new core functionality in the release and the emulator needs to be restarted before executing the upgrade scripts. If this instruction exists, a temporary release will be created which consists of the new version erts, kernel, stdlib and sasl, and the old versions of all other applications. After restarting the emulator with this temporary release, the rest of the upgrade instructions are executed, including loading of new versions. 'restart_emulator' can be used by any application if a restart of the emulator is needed after the upgrade instructions have been executed. In this case, the emulator will be restarted with the new release (i.e. not a tempoarary one) after all other upgrade instructions for all applications have been excecuted.
Diffstat (limited to 'lib/sasl/test/systools_SUITE.erl')
-rw-r--r--lib/sasl/test/systools_SUITE.erl12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/sasl/test/systools_SUITE.erl b/lib/sasl/test/systools_SUITE.erl
index 5b3abad219..4cf6aefea9 100644
--- a/lib/sasl/test/systools_SUITE.erl
+++ b/lib/sasl/test/systools_SUITE.erl
@@ -1157,7 +1157,7 @@ normal_relup(Config) when is_list(Config) ->
?line ok = file:set_cwd(LatestDir),
%% OTP-2561: Check that the option 'restart_emulator' generates a
- %% "restart_new_emulator" instruction.
+ %% "restart_emulator" instruction.
?line {ok, _ , _, []} =
systools:make_relup(LatestName, [LatestName1], [LatestName1],
[{path, P},restart_emulator,silent]),
@@ -1256,19 +1256,19 @@ check_relup_up_only(UpVsnL) ->
check_restart_emulator() ->
{ok, [{_V1, [{_, _, Up}], [{_, _, Dn}]}]} = file:consult(relup),
- restart_new_emulator = lists:last(Up),
- restart_new_emulator = lists:last(Dn),
+ restart_emulator = lists:last(Up),
+ restart_emulator = lists:last(Dn),
ok.
check_restart_emulator_up_only() ->
{ok, [{_V1, [{_, _, Up}], []}]} = file:consult(relup),
- restart_new_emulator = lists:last(Up),
+ restart_emulator = lists:last(Up),
ok.
check_restart_emulator_diff_erts() ->
{ok, [{_V1, [{_, _, Up}], [{_, _, Dn}]}]} = file:consult(relup),
[restart_new_emulator|_] = Up,
- restart_new_emulator = lists:last(Dn),
+ restart_emulator = lists:last(Dn),
ok.
%% make_relup
@@ -1444,7 +1444,7 @@ regexp_relup(Config) ->
%% Upgrade fe 2.1.1 -> 3.1
%% Shall match the second entry in fe-3.1 appup. Have added a
%% restart_new_emulator instruction there to distinguish it from
%% the first entry...
?line {ok, _, _, []} =
systools:make_relup(LatestName, [LatestName1], [], [{path, P}, silent]),
@@ -1444,7 +1444,7 @@ regexp_relup(Config) ->
%% Upgrade fe 2.1.1 -> 3.1
%% Shall match the second entry in fe-3.1 appup. Have added a
- %% restart_new_emulator instruction there to distinguish it from
+ %% restart_emulator instruction there to distinguish it from
%% the first entry...
?line {ok, _, _, []} =